@@ -7,7 +7,7 @@ from fedmsg.commands import command
 extra_args = []
 
 
-@command(extra_args=extra_args)
+@command(name="fedmsg-irc", extra_args=extra_args, daemonizable=True)
 def ircbot(**kw):
     """ Relay connections from active loggers to the bus. """
 
